
import React from "react"
import VisibilityIcon from "./VisibilityIcon.jsx"
import AccessButtonGroup from "./AccessButtonGroup.jsx"
import Breadcrumbs from "./Breadcrumbs.jsx"
import ViewDate from "./ViewDate.jsx"
import Uhepp from "./Uhepp.jsx"

/**
 * Main UX component to show plots including the its edit menu
 *
 * The dashboard provides ux components to view and manipulate plots. The
 * dashboard encompasses columns for a left sidebar with the modification
 * menu, the main column with the actual plot and a right sidebar with
 * metadata about the plot. The dashboard expects to be mounted within a
 * bootstrap container component.
 */
const Dashboard = ({title, visibility, breadcrumbs, viewdate, uuid}) => (
<div className="row">
  <div className="col-md-4 col-lg-3 sidebar bg-light shadow"> 
    Menu
  </div>

  <div className="col-md-6 col-lg-7"> 
    <Breadcrumbs content={breadcrumbs} />
    
    <h1 className="mb-0 controls-head">
        <span>{ title } <VisibilityIcon level={visibility} /></span>
        <span><AccessButtonGroup /></span>
    </h1>

    <ViewDate data={viewdate} />
    
   <Uhepp width={555} height={400} uuid={uuid} />
  </div>

  <div className="col-md-2 sidebar border-left">
    Metadata
  </div>
</div>
)

export default Dashboard
